@@ -8,8 +8,8 @@ function(lm.out, pdf=FALSE, width=5, height=5, manage.gr=FALSE, ...) {
 
   # pdf graphics option
   if (pdf) {
-    pdf.file <- "RegResiduals.pdf"
-    pdf(file=pdf.file, width=width, height=height)
+    pdf_file <- "RegResiduals.pdf"
+    pdf(file=pdf_file, width=width, height=height)
   }
 
   # keep track of the plot in this routine
@@ -21,16 +21,16 @@ function(lm.out, pdf=FALSE, width=5, height=5, manage.gr=FALSE, ...) {
 
   # frequency distribution of residuals
   .dn.main(lm.out$residuals, 
-    col.fill=getOption("bar.fill"),
-    col.bg=getOption("panel.fill"), 
-    col.box=getOption("panel.color"),
+    col_fill=getOption("bar_fill"),
+    col.bg=getOption("panel_fill"), 
+    col.box=getOption("panel_color"),
     col.nrm="gray40", col.gen="gray40",
-    col.fill.nrm="transparent", col.fill.gen="transparent",
+    col_fill_nrm="transparent", col_fill_gen="transparent",
     xlab="Residuals", quiet=TRUE)
 
   if (pdf) {
     dev.off()
-    .showfile(pdf.file, "residuals plot")
+    .showfile(pdf_file, "residuals plot")
   }
 
   invisible(list(i=plt.i, ttl=plt.title))
