@@ -1,8 +1,8 @@
 .reg4Pred <-
 function(lm.out, brief, 
-         n.keep, digits.d, show.R,
-         new.data, pred.sort, pred.rows, scatter.coef,
-         in.data.frame, X1.new, X2.new, X3.new, X4.new, X5.new, X6.new) {
+         n.keep, digits_d, show_R,
+         new.data, pred_sort, pred_rows, scatter_coef,
+         in.data.frame, X1_new, X2_new, X3_new, X4_new, X5_new, X6_new) {
 
   nm <- all.vars(lm.out$terms)  # names of vars in the model
   n.vars <- length(nm)
@@ -15,7 +15,7 @@ function(lm.out, brief,
 # prediction intervals
 # --------------------
      
-  if (show.R) {
+  if (show_R) {
     txt <- "predict(model, interval=\"prediction\")"
     tx[length(tx)+1] <- paste("> ", txt, sep="", "\n")
     txt <- "predict(model, interval=\"confidence\")"
@@ -25,8 +25,8 @@ function(lm.out, brief,
 
   tx[length(tx)+1] <- "Data, Predicted, Standard Error of Forecast, 95% Prediction Intervals"
   tx[length(tx)+1] <- "   [sorted by lower bound of prediction interval]"
-  if (pred.rows < n.keep  &&  !new.data) 
-    tx[length(tx)+1] <- "   [to see all intervals do pred.rows=\"all\"]"
+  if (pred_rows < n.keep  &&  !new.data) 
+    tx[length(tx)+1] <- "   [to see all intervals do pred_rows=\"all\"]"
   
   if (!new.data) {
     c.int <- data.frame(predict(lm.out, interval="confidence"))
@@ -41,9 +41,9 @@ function(lm.out, brief,
     out <- data.frame(out)
   }
   else {
-    Xnew.val <- list(X1.new)
+    Xnew.val <- list(X1_new)
     if (n.vars > 2) for (i in 2:(n.pred)) {
-      pp <- eval(parse(text=paste("X", toString(i),".new",sep="")))
+      pp <- eval(parse(text=paste("X", toString(i),"_new",sep="")))
       Xnew.val <- c(Xnew.val, list(pp))
     }
     Xnew <- expand.grid(Xnew.val)
@@ -61,7 +61,7 @@ function(lm.out, brief,
     names(out)[n.vars] <- nm[1]
   }
 
-  if (pred.sort == "predint") {
+  if (pred_sort == "predint") {
     o <- order(out[,n.vars+3])  # lower bound of pred interval
     out <- out[o,]
   }
@@ -81,27 +81,27 @@ function(lm.out, brief,
   predmm[1] <- min(out[n.vars+5])
   predmm[2] <- max(out[n.vars+5])
 
-  min.row <- which(out[n.vars+5] == min(out[n.vars+5]))
-  if (length(min.row) > 1) min.row <- min.row[1]
-  min.nm <- rownames(out[min.row,])
+  min_row <- which(out[n.vars+5] == min(out[n.vars+5]))
+  if (length(min_row) > 1) min_row <- min_row[1]
+  min_nm <- rownames(out[min_row,])
 
   max.row <- which(out[n.vars+5] == max(out[n.vars+5]))
   if (length(max.row) > 1) max.row <- max.row[1]
   max.side <- ifelse (max.row < n.keep/2, max.side <- TRUE, max.side <- FALSE)
   max.nm <- rownames(out[max.row,])
 
-  names(predmm) <- c(min.nm, max.nm)
+  names(predmm) <- c(min_nm, max.nm)
 
 
   if (!new.data) {
 
-    if (pred.rows == nrow(out)) {
+    if (pred_rows == nrow(out)) {
       r <- 1:nrow(out)
-      tx2 <- .prntbl(out[r,], digits.d)
+      tx2 <- .prntbl(out[r,], digits_d)
     }
 
     else {
-      piece.rows <- round(pred.rows/3,0)
+      piece.rows <- round(pred_rows/3,0)
       if (piece.rows < 1) piece.rows <- 1
       pr2 <- floor(piece.rows/2)
 
@@ -110,7 +110,7 @@ function(lm.out, brief,
       else
         r1 <- 1:piece.rows
 
-      r2 <- (min.row-pr2):(min.row+pr2)
+      r2 <- (min_row-pr2):(min_row+pr2)
 
       if (!max.side)
         r3 <- (max.row-pr2):(min(max.row+pr2,nrow(out)))
@@ -121,13 +121,13 @@ function(lm.out, brief,
       r <- c(r1,r2,r3)
       b1 <- which(r == r2[1])
       b2 <- which(r == r3[1])
-      tx2 <- .prntbl(out[r,], digits.d, brk=c(b1,b2))
+      tx2 <- .prntbl(out[r,], digits_d, brk=c(b1,b2))
     }
 
   }
 
   else   # new data 
-    tx2 <- .prntbl(out, digits.d)   # prefer to have row.names=FALSE
+    tx2 <- .prntbl(out, digits_d)   # prefer to have row.names=FALSE
 
   for (i in 1:length(tx2)) tx[length(tx)+1] <- tx2[i]
 
